==> lxqt-panel-2.2.1.tar.xz: lxqt-panel-2.2.1/plugin-desktopswitch/translations/desktopswitch_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>DesktopSwitch</name>
    <message>
        <location filename="../desktopswitch.cpp" line="96"/>
        <source>Switch to desktop %1</source>
        <translation>Prebaci na radnu površinu %1</translation>
    </message>
    <message>
        <location filename="../desktopswitch.cpp" line="171"/>
        <location filename="../desktopswitch.cpp" line="182"/>
        <source>Desktop %1</source>
        <translation>Radna površina %1</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchConfiguration</name>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="14"/>
        <source>DesktopSwitch Settings</source>
        <translation>Prebacivanje između radnih površina – Postavke</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="46"/>
        <source>Number of rows:</source>
        <translation>Broj redaka:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="39"/>
        <source>Desktop labels:</source>
        <translation>Oznake za radnu površinu:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Izgled</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="54"/>
        <source>Numbers</source>
        <translation>Brojevi</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="59"/>
        <source>Names</source>
        <translation>Imena</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="64"/>
        <source>None</source>
        <translation>Bez</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="72"/>
        <source>If checked, widget will be just an indicator</source>
        <translation>Ako je označeno, programčić će biti samo indikator</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="75"/>
        <source>Show only active desktop</source>
        <translation>Prikaži samo aktivne radne površine</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="85"/>
        <source>Desktop names</source>
        <translation>Imena radnih površina</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.cpp" line="78"/>
        <source>Desktop %1:</source>
        <translation>Radna površina %1:</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchUnsupported</name>
    <message>
        <location filename="../desktopswitch.cpp" line="343"/>
        <source>n/a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopswitch.cpp" line="345"/>
        <source>DesktopSwitch is unsupported on current platform: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-panel_2.2.2.orig.tar.xz: lxqt-panel-2.2.2/plugin-desktopswitch/translations/desktopswitch_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>DesktopSwitch</name>
    <message>
        <location filename="../desktopswitch.cpp" line="96"/>
        <source>Switch to desktop %1</source>
        <translation>Prebaci na radnu površinu %1</translation>
    </message>
    <message>
        <location filename="../desktopswitch.cpp" line="171"/>
        <location filename="../desktopswitch.cpp" line="182"/>
        <source>Desktop %1</source>
        <translation>Radna površina %1</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchConfiguration</name>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="14"/>
        <source>DesktopSwitch Settings</source>
        <translation>Prebacivanje između radnih površina – Postavke</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="46"/>
        <source>Number of rows:</source>
        <translation>Broj redaka:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="39"/>
        <source>Desktop labels:</source>
        <translation>Oznake za radnu površinu:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Izgled</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="54"/>
        <source>Numbers</source>
        <translation>Brojevi</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="59"/>
        <source>Names</source>
        <translation>Imena</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="64"/>
        <source>None</source>
        <translation>Bez</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="72"/>
        <source>If checked, widget will be just an indicator</source>
        <translation>Ako je označeno, programčić će biti samo indikator</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="75"/>
        <source>Show only active desktop</source>
        <translation>Prikaži samo aktivne radne površine</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="85"/>
        <source>Desktop names</source>
        <translation>Imena radnih površina</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.cpp" line="78"/>
        <source>Desktop %1:</source>
        <translation>Radna površina %1:</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchUnsupported</name>
    <message>
        <location filename="../desktopswitch.cpp" line="343"/>
        <source>n/a</source>
        <translation>--</translation>
    </message>
    <message>
        <location filename="../desktopswitch.cpp" line="345"/>
        <source>DesktopSwitch is unsupported on current platform: %1</source>
        <translation>DesktopSwitch nije podržan na trenutačnoj platformi: %1</translation>
    </message>
</context>
</TS>
